m_getfld2: ERR2 means a read error, thus name it IOERR2
authormarkus schnalke <meillo@marmaro.de>
Thu, 12 Nov 2015 07:23:04 +0000 (08:23 +0100)
committermarkus schnalke <meillo@marmaro.de>
Thu, 12 Nov 2015 21:41:55 +0000 (22:41 +0100)
h/mh.h
sbr/m_getfld2.c
uip/distsbr.c
uip/mhbuild.c
uip/mhl.c
uip/mhparse.c
uip/pick.c
uip/slocal.c
uip/sortm.c
uip/spost.c
uip/whom.c

--- a/uip/mhl.c
+++ b/uip/mhl.c
@@ -699,7 +699,7 @@ mhlfile(FILE *fp, char *mname, int ofilen, int ofilec)
 
                case LENERR2:
                case FMTERR2:
-               case ERR2:
+               case IOERR2:
                        advise(NULL, "format error in message %s", mname);
                        exitstat++;
                        return;
index 1cbefed..257bc66 100644 (file)
@@ -269,7 +269,7 @@ get_content(FILE *in, char *file, int toplevel)
 
                case LENERR2:
                case FMTERR2:
-               case ERR2:
+               case IOERR2:
                        adios(EX_DATAERR, NULL, "message format error in component #%d",
                                        compnum);
 
index a5e658d..993527b 100644 (file)
@@ -1262,7 +1262,7 @@ plist
 
                case LENERR2:
                case FMTERR2:
-               case ERR2:
+               case IOERR2:
                        advise(NULL, "format error in message %d", msgnum);
                        /* FALL */
 
index 5760a83..c3b45e8 100644 (file)
@@ -795,7 +795,7 @@ parse(int fd)
 
                case LENERR2:
                case FMTERR2:
-               case ERR2:
+               case IOERR2:
                        advise(NULL, "format error in message");
                        break;
 
index 43dc7dc..61953e1 100644 (file)
@@ -355,7 +355,7 @@ get_fields(char *datesw, int msg, struct smsg *smsg)
 
                case LENERR2:
                case FMTERR2:
-               case ERR2:
+               case IOERR2:
                        admonish(NULL, "format error in message %d (header #%d)", msg, compnum);
                        if (datecomp) {
                                free(datecomp);
index 6282e75..04479a1 100644 (file)
@@ -253,7 +253,7 @@ main(int argc, char **argv)
 
                case LENERR2:
                case FMTERR2:
-               case ERR2:
+               case IOERR2:
                        adios(EX_DATAERR, NULL, "message format error in component #%d",
                                        compnum);
 
index e1aab77..a72c84f 100644 (file)
@@ -225,7 +225,7 @@ process(char *file)
 
                case LENERR2:
                case FMTERR2:
-               case ERR2:
+               case IOERR2:
                        adios(EX_DATAERR, NULL, "message format error in component #%d",
                                        compnum);
diff --git a/h/mh.h b/h/mh.h
index a93d9a9..8107a3e 100644 (file)
--- a/h/mh.h
+++ b/h/mh.h
@@ -214,7 +214,7 @@ struct field {
 enum state {
        LENERR2 = -2,
        FMTERR2 = -3,
-       ERR2 = -1,
+       IOERR2 = -1,
        FLD2 = 0,
        BODY2,
        FILEEOF2,
index a17eb03..5920425 100644 (file)
@@ -27,7 +27,7 @@ static size_t copyname(char *, char *);
 
 /*
 ** For the states FLD2, BODY2 and FMTERR2 memory is allocated for f->value.
** For the states LENERR2, ERR2 and FILEEOF2 no memory is allocated.
 */
 enum state
 m_getfld2(enum state s, struct field *f, FILE *msg)
@@ -42,7 +42,7 @@ m_getfld2(enum state s, struct field *f, FILE *msg)
                if (feof(msg)) {
                        return FILEEOF2;
                } else {
-                       return ERR2;
+                       return IOERR2;
                }
        }
 
@@ -95,7 +95,7 @@ m_getfld2(enum state s, struct field *f, FILE *msg)
                        nchars = getline(&tmpline, &len, msg);
                        if (nchars <= 0) {
                                free(tmpline);
-                               return ERR2;
+                               return IOERR2;
                        }
 
                        if (nchars >= NAMESZ) {
@@ -125,7 +125,7 @@ m_getfld2(enum state s, struct field *f, FILE *msg)
 
                if (falted == FAIL) {
                        free(tmpline);
-                       return ERR2;
+                       return IOERR2;
                }
 
                free(tmpline);
index 494c298..9c20fda 100644 (file)
@@ -77,7 +77,7 @@ distout(char *drft, char *msgnam, char *backup)
 
                case LENERR2:
                case FMTERR2:
-               case ERR2:
+               case IOERR2:
                        advise(NULL, "Please re-edit draft and fix that header.");
 leave_bad: ;
                        fclose(ifp);
@@ -194,7 +194,7 @@ ready_msg(char *msgnam)
 
                case LENERR2:
                case FMTERR2:
-               case ERR2:
+               case IOERR2:
                        advise(NULL, "format error in message %s", msgnam);
                        return NOTOK;
 
index b8e9f93..ec5623a 100644 (file)
@@ -385,7 +385,7 @@ build_mime(char *infile)
 
                case LENERR2:
                case FMTERR2:
-               case ERR2:
+               case IOERR2:
                        adios(EX_CONFIG, NULL, "message format error in component #%d",
                                        compnum);
 
@@ -27,7 +27,7 @@ static size_t copyname(char *, char *);
 /*
 ** For the states FLD2, BODY2 and FMTERR2 memory is allocated for f->value.
-** For the states LENERR2, ERR2 and FILEEOF2 no memory is allocated.
+** For the states LENERR2, IOERR2 and FILEEOF2 no memory is allocated.
 */
 enum state
index fcdb77f..8becba9 100644 (file)